@@ -89,8 +89,8 @@ class IHubSensors:
 
         else:
             self.chargerobject = ChargerObject(
-                data_type=[],
-                listenerentity="",
+                data_type=self.chargertype.charger.native_chargerstates,
+                listenerentity="no entity",
                 init_override=True
             )
             resultdict[self.chargerobject.entity] = True
