@@ -6,15 +6,10 @@ from ...models.hourselection.const import (
     CAUTIONHOURTYPE_INTERMEDIATE,
     CAUTIONHOURTYPE
 )
-from enum import Enum
 from .hoursselection_helpers import HourSelectionHelpers
 from ...models.hourselection.hourobject import HourObject, HourObjectExtended
 from ...models.hourselection.hourselectionmodels import HourSelectionModel, HourSelectionOptions
-
-class HourTypeList(Enum):
-    NonHour = 0
-    CautionHour = 1
-    DynCautionHour = 2
+from ...models.hourselection.hourtypelist import HourTypeList
 
 
 class Hoursselection:
@@ -53,17 +48,17 @@ class Hoursselection:
 
     @property
     def non_hours(self) -> list:
-        self._update_hour_lists(self.model.hours.hours_today, self.model.hours.hours_tomorrow, listtype=HourTypeList.NonHour)
+        self._update_hour_lists(listtype=HourTypeList.NonHour)
         return self.model.hours.non_hours
 
     @property
     def caution_hours(self) -> list:
-        self._update_hour_lists(self.model.hours.hours_today, self.model.hours.hours_tomorrow, listtype=HourTypeList.CautionHour)
+        self._update_hour_lists(listtype=HourTypeList.CautionHour)
         return self.model.hours.caution_hours
 
     @property
     def dynamic_caution_hours(self) -> dict:
-        self._update_hour_lists(self.model.hours.hours_today, self.model.hours.hours_tomorrow, listtype=HourTypeList.DynCautionHour)
+        self._update_hour_lists(listtype=HourTypeList.DynCautionHour)
         return self.model.hours.dynamic_caution_hours
 
     @property
@@ -87,14 +82,22 @@ class Hoursselection:
         self.model.prices_tomorrow = HourSelectionHelpers._convert_none_list(val)
         self.update()
 
+    def get_average_kwh_price(self, testhour:int = None):
+        ret = self._get_charge_or_price(testhour=testhour)
+        return round(sum(ret.values())/len(ret),2)
+        
+    def get_total_charge(self, currentpeak:float, testhour:int = None) -> float:
+        ret = self._get_charge_or_price(currentpeak, testhour)
+        return round(sum(ret.values()),1)
+
     def update(
         self, 
         testhour:int = None
         ):
         if testhour is not None:
             self._base_mock_hour = testhour
-        today_ready = self._update_per_day(self.prices)
-        hours_today = self._add_remove_limited_hours(today_ready)
+        hours_ready = self._update_per_day(self.prices)
+        hours = self._add_remove_limited_hours(hours_ready)
         hours_tomorrow = HourObject([],[],dict())
         if self.prices_tomorrow is not None and len(self.prices_tomorrow) > 0:
             self.options.conserve_top_up = False
@@ -102,96 +105,10 @@ class Hoursselection:
                 self._update_per_day(self.prices_tomorrow)
                 )
 
-        self.model.hours.hours_today = hours_today
+        self.model.hours.hours_today = hours
         self.model.hours.hours_tomorrow = hours_tomorrow
-        self._update_hour_lists(hours_today=hours_today, hours_tomorrow=hours_tomorrow, testhour=testhour)
+        self._update_hour_lists(testhour=testhour)
         
-    def _set_top_up(
-        self, 
-        testhour: int = None
-        ) -> None:
-        if self.model.options.allow_top_up is True and self.prices_tomorrow is not None and len(self.prices_tomorrow) > 0:
-            ret = top_up(TopUpDTO(
-                self.model.hours.non_hours, 
-                self.model.hours.caution_hours, 
-                self.model.hours.dynamic_caution_hours, 
-                self.model.options.absolute_top_price,
-                self.model.options.min_price,
-                testhour if testhour is not None else self._base_mock_hour if self._base_mock_hour is not None else datetime.now().hour, 
-                self.model.hours.hours_today, 
-                self.model.hours.hours_tomorrow, 
-                self.model.prices_today, 
-                self.model.prices_tomorrow
-                ))
-            if ret.nh != self.model.hours.non_hours:
-                self.model.options.conserve_top_up = True
-                self.model.hours.non_hours = ret.nh
-                self.model.hours.caution_hours = ret.ch
-                self.model.hours.dynamic_caution_hours = ret.dyn_ch
-
-    def _update_hour_lists(
-        self, 
-        hours_today:HourObject, 
-        hours_tomorrow:HourObject, 
-        testhour:int = None, 
-        listtype:HourTypeList = None,
-        ) -> None:
-        hour = testhour if testhour is not None else self._base_mock_hour if self._base_mock_hour is not None else datetime.now().hour
-        if listtype is not None:
-            match listtype:
-                case HourTypeList.NonHour:
-                    self._update_nonhour_list(hours_today, hours_tomorrow, hour)
-                case HourTypeList.CautionHour:
-                    self._update_cautionhour_list(hours_today, hours_tomorrow, hour)
-                case HourTypeList.DynCautionHour:
-                    self._update_dyn_cautionhour_dict(hours_today, hours_tomorrow, hour)
-                case _:
-                    pass
-        else:
-            self._update_nonhour_list(hours_today, hours_tomorrow, hour)
-            self._update_cautionhour_list(hours_today, hours_tomorrow, hour)
-            self._update_dyn_cautionhour_dict(hours_today, hours_tomorrow, hour)
-        self._set_top_up(hour)
-        
-    def _update_nonhour_list(
-        self, 
-        hours_today:HourObject, 
-        hours_tomorrow:HourObject, 
-        hour:int
-        ) -> None:
-        if self.options.conserve_top_up is False:
-            self.model.hours.non_hours = []
-            self.model.hours.non_hours.extend(h for h in hours_today.nh if h >= hour)
-            self.model.hours.non_hours.extend(h for h in hours_tomorrow.nh if h < hour)
-        # else:
-        #     self.model.hours.non_hours = [h for h in self.model.hours.non_hours if h >= hour]
-            
-    def _update_cautionhour_list(
-        self, 
-        hours_today:HourObject, 
-        hours_tomorrow:HourObject, 
-        hour:int
-        ) -> None:
-        if self.options.conserve_top_up is False:
-            self.model.hours.caution_hours = []
-            self.model.hours.caution_hours.extend(h for h in hours_today.ch if h >= hour)
-            self.model.hours.caution_hours.extend(h for h in hours_tomorrow.ch if h < hour)
-        # else:
-        #     self.model.hours.caution_hours = [h for h in self.model.hours.caution_hours if h >= hour]
-
-    def _update_dyn_cautionhour_dict(
-        self, 
-        hours_today:HourObject, 
-        hours_tomorrow:HourObject, 
-        hour:int
-        ) -> None:
-        if self.options.conserve_top_up is False:
-            self.model.hours.dynamic_caution_hours = dict()
-            self.model.hours.dynamic_caution_hours.update({k: v for k, v in hours_today.dyn_ch.items() if k >= hour})
-            self.model.hours.dynamic_caution_hours.update({k: v for k, v in hours_tomorrow.dyn_ch.items() if k < hour})
-        #else:
-        #    self.model.hours.dynamic_caution_hours.pop(h for h in hours_today.nh if h < hour)
-
     def _update_per_day(self, prices: list) -> HourObjectExtended:
         pricedict = dict
         if prices is not None and len(prices) > 1:
@@ -209,31 +126,110 @@ class Hoursselection:
                     pricedict
                     )
             return HourObjectExtended([], [], dict(), pricedict)
+
+    def _update_hour_lists(
+        self, 
+        testhour:int = None, 
+        listtype:HourTypeList = None,
+        ) -> None:
+        hour = self._set_hour(testhour)
+
+        if listtype is not None:
+            match listtype:
+                case HourTypeList.NonHour:
+                    self._update_nonhour_list(hour)
+                case HourTypeList.CautionHour:
+                    self._update_cautionhour_list(hour)
+                case HourTypeList.DynCautionHour:
+                    self._update_dyn_cautionhour_dict(hour)
+                case _:
+                    pass
+        else:
+            self._update_nonhour_list(hour)
+            self._update_cautionhour_list(hour)
+            self._update_dyn_cautionhour_dict(hour)
+        self._set_top_up(hour)
         
+    def _update_nonhour_list(
+        self, 
+        hour:int
+        ) -> None:
+        hours_today = self.model.hours.hours_today 
+        hours_tomorrow = self.model.hours.hours_tomorrow
+        if self.options.conserve_top_up is False:
+            self.model.hours.non_hours = []
+            self.model.hours.non_hours.extend(h for h in hours_today.nh if h >= hour)
+            self.model.hours.non_hours.extend(h for h in hours_tomorrow.nh if h < hour)
+            
+    def _update_cautionhour_list(
+        self, 
+        hour:int
+        ) -> None:
+        hours_today = self.model.hours.hours_today 
+        hours_tomorrow = self.model.hours.hours_tomorrow
+        if self.options.conserve_top_up is False:
+            self.model.hours.caution_hours = []
+            self.model.hours.caution_hours.extend(h for h in hours_today.ch if h >= hour)
+            self.model.hours.caution_hours.extend(h for h in hours_tomorrow.ch if h < hour)
+
+    def _update_dyn_cautionhour_dict(
+        self, 
+        hour:int
+        ) -> None:
+        hours_today = self.model.hours.hours_today 
+        hours_tomorrow = self.model.hours.hours_tomorrow
+        if self.options.conserve_top_up is False:
+            self.model.hours.dynamic_caution_hours = dict()
+            self.model.hours.dynamic_caution_hours.update({k: v for k, v in hours_today.dyn_ch.items() if k >= hour})
+            self.model.hours.dynamic_caution_hours.update({k: v for k, v in hours_tomorrow.dyn_ch.items() if k < hour})
+
+    def _set_top_up(
+        self, 
+        testhour: int = None
+        ) -> None:
+        if self.model.options.allow_top_up is True and self.prices_tomorrow is not None and len(self.prices_tomorrow) > 0:
+            ret = top_up(TopUpDTO(
+                self.model.hours.non_hours, 
+                self.model.hours.caution_hours, 
+                self.model.hours.dynamic_caution_hours, 
+                self.model.options.absolute_top_price,
+                self.model.options.min_price,
+                self._set_hour(testhour), 
+                self.model.hours.hours_today, 
+                self.model.hours.hours_tomorrow, 
+                self.model.prices_today, 
+                self.model.prices_tomorrow
+                ))
+            if ret.nh != self.model.hours.non_hours:
+                self.model.options.conserve_top_up = True
+                self.model.hours.non_hours = ret.nh
+                self.model.hours.caution_hours = ret.ch
+                self.model.hours.dynamic_caution_hours = ret.dyn_ch
+
     def _add_remove_limited_hours(self, hours: HourObjectExtended) -> HourObject:
         """Removes cheap hours and adds expensive hours set by user limitation"""
         if hours is None:
             return HourObject([],[],dict())
 
         if self.model.options.absolute_top_price is not None:
-                ret = self._add_expensive_non_hours(hours)
+                ret = self._add_expensive_hours(hours)
         else: 
             ret = HourObject(hours.nh, hours.ch, hours.dyn_ch)
         if self.model.options.min_price > 0:
             ret = self._remove_cheap_hours(hours)
         return ret
 
-    def _remove_cheap_hours(self, hours: HourObjectExtended) -> HourObject:
-        lst = (h for h in hours.pricedict if hours.pricedict[h] < self.model.options.min_price)
+    def _remove_cheap_hours(self, readyhours: HourObjectExtended) -> HourObject:
+        lst = (h for h in readyhours.pricedict if readyhours.pricedict[h] < self.model.options.min_price)
         for h in lst:
-            if h in hours.nh:
-                hours.nh.remove(h)
-            elif h in hours.ch:
-                hours.ch.remove(h)
-                hours.dyn_ch.pop(h)    
-        return HourObject(hours.nh, hours.ch, hours.dyn_ch)
+            if h in readyhours.nh:
+                readyhours.nh.remove(h)
+            elif h in readyhours.ch:
+                readyhours.ch.remove(h)
+                readyhours.dyn_ch.pop(h)    
+        return HourObject(readyhours.nh, readyhours.ch, readyhours.dyn_ch)
 
-    def _add_expensive_non_hours(self, readyhours:HourObjectExtended) -> HourObject:
+    def _add_expensive_hours(self, readyhours:HourObjectExtended) -> HourObject:
         lst = (h for h in readyhours.pricedict if readyhours.pricedict[h] >= self.model.options.absolute_top_price)
         for h in lst:
             if h not in readyhours.nh:
@@ -264,14 +260,6 @@ class Hoursselection:
                 _nh.append(p)
 
         return HourObject(_nh, _ch, _dyn_ch)
-    
-    def get_average_kwh_price(self, testhour:int = None):
-        ret = self._get_charge_or_price(testhour=testhour)
-        return round(sum(ret.values())/len(ret),2)
-        
-    def get_total_charge(self, currentpeak:float, testhour:int = None) -> float:
-        ret = self._get_charge_or_price(currentpeak, testhour)
-        return round(sum(ret.values()),1)
 
     def _get_charge_or_price(self, currentpeak:float = None, testhour:int = None) -> dict:
         hour = self._set_hour(testhour)
@@ -314,5 +302,4 @@ class Hoursselection:
         return ret
 
     def _set_hour(self, testhour:int = None) -> int:
-        return datetime.now().hour if testhour is None else testhour
-
+        return testhour if testhour is not None else self._base_mock_hour if self._base_mock_hour is not None else datetime.now().hour
