@@ -22,7 +22,6 @@ class PriceAwareHours(Hours):
         )
         self._hass = hub.state_machine
         self._prices = []
-        self._is_initialized = False
         super().__init__(price_aware=True)
 
     @property
@@ -94,6 +93,8 @@ class PriceAwareHours(Hours):
             except ZeroDivisionError as e:
                 _LOGGER.warning(e)
             return 0
+        _LOGGER.debug("get avg kwh price, not initialized")
+        return "-"
 
     def get_total_charge(self):
         if self._is_initialized:
@@ -102,6 +103,8 @@ class PriceAwareHours(Hours):
             except ZeroDivisionError as e:
                 _LOGGER.warning(e)
             return 0
+        _LOGGER.debug("get avg kwh price, not initialized")
+        return "-"
 
     @staticmethod
     def _set_absolute_top_price(_input) -> float:
